# vs-rgtools

> [!CAUTION]
> This package is deprecated!
> Please use https://github.com/Jaded-Encoding-Thaumaturgy/vs-jetpack instead.

Wrapper for RGVS, RGSF, and various other functions

#### Dependencies

- [vstools](https://github.com/Jaded-Encoding-Thaumaturgy/vs-tools/)
- [RGVS](https://github.com/vapoursynth/vs-removegrain)
- [RGSF](https://github.com/IFeelBloated/RGSF)
- [zsmooth](https://github.com/adworacz/zsmooth)
- [Akarin Expr](https://github.com/AkarinVS/vapoursynth-plugin)

# How to install
**This package is deprecated!**

Please install https://pypi.org/p/vsjetpack instead.
